Config

Struct Config 

pub struct Config {
Show 14 fields pub log: PathBuf, pub conn: Connection, pub local_music_dir: PathBuf, pub playcount_sticker: String, pub lastplayed_sticker: String, pub played_thresh: f64, pub poll_interval_ms: u64, pub commands_chan: String, pub playcount_command: String, pub playcount_command_args: Vec<String>, pub rating_sticker: String, pub ratings_command: String, pub ratings_command_args: Vec<String>, pub gen_cmds: Vec<GeneralizedCommandDefn>, /* private fields */
}
This is the most recent mppopmd configuration struct.

Fields

log: PathBuf

Location of log file

conn: Connection

How to connect to mpd

local_music_dir: PathBuf

The `mpd’ root music directory, relative to the host on which this daemon is running

playcount_sticker: String

Sticker name under which to store playcounts

lastplayed_sticker: String

Sticker name under which to store the last played timestamp

played_thresh: f64

Percentage threshold, expressed as a number between zero & one, for considering a song to have been played

poll_interval_ms: u64

The interval, in milliseconds, at which to poll `mpd’ for the current state

commands_chan: String

Channel to setup for assorted commands– channel names must satisfy “[-a-zA-Z-9_.:]+”

playcount_command: String

Command, with replacement parameters, to be run when a song’s playcount is incremented

playcount_command_args: Vec<String>

Args, with replacement parameters, for the playcount command

rating_sticker: String

Sticker under which to store song ratings, as a textual representation of a number in [0,255]

ratings_command: String

Command, with replacement parameters, to be run when a song is rated

ratings_command_args: Vec<String>

Args, with replacement parameters, for the ratings command

gen_cmds: Vec<GeneralizedCommandDefn>

Generalized commands